#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 httpd-shed
version:              0.4.1.2
visibility:           public
id:                   httpd-shed-0.4.1.2-Dkw0U5ugsgQIRipvZATryi
key:                  httpd-shed-0.4.1.2-Dkw0U5ugsgQIRipvZATryi
license:              BSD-3-Clause
copyright:            (c) 2009 Andy Gill
maintainer:           Ganesh Sittampalam
author:               Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis:             A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.

category:             Network, Web
abi:                  040e5c6c6d2d5e7358ab2ddda47798ad
exposed:              True
exposed-modules:      Network.Shed.Httpd
import-dirs:          /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/httpd-shed-0.4.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-httpd-shed
hs-libraries:         HShttpd-shed-0.4.1.2-Dkw0U5ugsgQIRipvZATryi
depends:
    base-4.18.2.1 network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    network-bsd-2.8.1.0-5jWyJQYzAT48Le8IwU4Mfy
    network-uri-2.6.4.2-1CJs0qlSGKv7cmTNxU9YR0

haddock-interfaces:   /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html:         /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

